@@ -1,35 +1,23 @@
 /*
  * This file is part of the Shiboken Python Bindings Generator project.
  *
- * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+ * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
  *
  * Contact: PySide team <contact@pyside.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation. Please
- * review the following information to ensure the GNU Lesser General
- * Public License version 2.1 requirements will be met:
- * http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * As a special exception to the GNU Lesser General Public License
- * version 2.1, the object code form of a "work that uses the Library"
- * may incorporate material from a header file that is part of the
- * Library.  You may distribute such object code under terms of your
- * choice, provided that the incorporated material (i) does not exceed
- * more than 5% of the total size of the Library; and (ii) is limited to
- * numerical parameters, data structure layouts, accessors, macros,
- * inline functions and templates.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef HELPER_H
@@ -43,6 +31,12 @@
 namespace Shiboken
 {
 
+template<typename A>
+inline PyObject* makeTuple(const A& a)
+{
+    return PyTuple_Pack(1, AutoDecRef(Converter<A>::toPython(a)).object());
+}
+
 template<typename A, typename B>
 inline PyObject* makeTuple(const A& a, const B& b)
 {
@@ -79,13 +73,16 @@ inline PyObject* makeTuple(const A& a, const B& b, const C& c, const D& d, const
 
 /**
 * It transforms a python sequence into two C variables, argc and argv.
-* If the sequence is empty and defaultAppName was provided, argc will be 1 and
-* argv will have a copy of defaultAppName.
+* This function tries to find the application (script) name and put it into argv[0], if
+* the application name can't be guessed, defaultAppName will be used.
 *
-* \note argc and argv *should* be deleted by the user.
+* No memory is allocated is an error occur.
+*
+* \note argc must be a valid address.
+* \note The argv array is allocated using new operator and each item is allocated using malloc.
 * \returns True on sucess, false otherwise.
 */
-LIBSHIBOKEN_API bool PySequenceToArgcArgv(PyObject* argList, int* argc, char*** argv, const char* defaultAppName = 0);
+LIBSHIBOKEN_API bool sequenceToArgcArgv(PyObject* argList, int* argc, char*** argv, const char* defaultAppName = 0);
 
 /**
  * Convert a python sequence into a heap-allocated array of ints.
